==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/AssigningPolarMarkerStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningPolarStyleEventArgsBaseDescriptionMetadata } from "./AssigningPolarStyleEventArgsBaseDescriptionMetadata";
import { AssigningPolarMarkerStyleEventArgsDescription } from "./AssigningPolarMarkerStyleEventArgsDescription";
/**
 * @hidden
 */
var AssigningPolarMarkerStyleEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(AssigningPolarMarkerStyleEventArgsDescriptionMetadata, _super);
    function AssigningPolarMarkerStyleEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningPolarMarkerStyleEventArgsDescriptionMetadata.b = function (a) {
        if (AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a == null) {
            AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningPolarMarkerStyleEventArgsDescriptionMetadata.c(AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a);
        }
        if (a.j(AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a);
    };
    AssigningPolarMarkerStyleEventArgsDescriptionMetadata.c = function (a) {
        AssigningPolarStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningPolarMarkerStyleEventArgsDescriptionMetadata.d = function (a) {
        AssigningPolarMarkerStyleEventArgsDescriptionMetadata.b(a);
        a.aa("AssigningPolarMarkerStyleEventArgs", function () { return new AssigningPolarMarkerStyleEventArgsDescription(); });
        a.z("AssigningPolarMarkerStyleEventArgs", AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a);
    };
    AssigningPolarMarkerStyleEventArgsDescriptionMetadata.$t = markType(AssigningPolarMarkerStyleEventArgsDescriptionMetadata, 'AssigningPolarMarkerStyleEventArgsDescriptionMetadata');
    AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a = null;
    return AssigningPolarMarkerStyleEventArgsDescriptionMetadata;
}(Base));
export { AssigningPolarMarkerStyleEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/AssigningPolarMarkerStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningPolarStyleEventArgsBaseDescriptionMetadata } from "./AssigningPolarStyleEventArgsBaseDescriptionMetadata";
import { AssigningPolarMarkerStyleEventArgsDescription } from "./AssigningPolarMarkerStyleEventArgsDescription";
/**
 * @hidden
 */
var AssigningPolarMarkerStyleEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(AssigningPolarMarkerStyleEventArgsDescriptionMetadata, _super);
    function AssigningPolarMarkerStyleEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningPolarMarkerStyleEventArgsDescriptionMetadata.b = function (a) {
        if (AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a == null) {
            AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningPolarMarkerStyleEventArgsDescriptionMetadata.c(AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a);
        }
        if (a.k(AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a);
    };
    AssigningPolarMarkerStyleEventArgsDescriptionMetadata.c = function (a) {
        AssigningPolarStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningPolarMarkerStyleEventArgsDescriptionMetadata.d = function (a) {
        AssigningPolarMarkerStyleEventArgsDescriptionMetadata.b(a);
        a.ac("AssigningPolarMarkerStyleEventArgs", function () { return new AssigningPolarMarkerStyleEventArgsDescription(); });
        a.ab("AssigningPolarMarkerStyleEventArgs", AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a);
    };
    AssigningPolarMarkerStyleEventArgsDescriptionMetadata.$t = markType(AssigningPolarMarkerStyleEventArgsDescriptionMetadata, 'AssigningPolarMarkerStyleEventArgsDescriptionMetadata');
    AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a = null;
    return AssigningPolarMarkerStyleEventArgsDescriptionMetadata;
}(Base));
export { AssigningPolarMarkerStyleEventArgsDescriptionMetadata };
